@@ -80,7 +80,9 @@ from borg import Borg
 from util import dbg, err, DEBUG, get_config_dir, dict_diff
 
 try:
-    import gconf
+    import gi
+    gi.require_version('GConf','2.0')
+    from gi.repository import GConf
 except ImportError:
     dbg('Unable to import gconf, GNOME defaults unavailable')
 
@@ -102,7 +104,6 @@ DEFAULTS = {
             'always_on_top'         : False,
             'hide_on_lose_focus'    : False,
             'sticky'                : False,
-            'try_posix_regexp'      : platform.system() != 'Linux',
             'use_custom_url_handler': False,
             'custom_url_handler'    : '',
             'disable_real_transparency' : False,
@@ -201,7 +202,6 @@ DEFAULTS = {
         'profiles': {
             'default':  {
                 'allow_bold'            : True,
-                'antialias'             : True,
                 'audible_bell'          : False,
                 'visible_bell'          : False,
                 'urgent_bell'           : False,
@@ -209,7 +209,6 @@ DEFAULTS = {
                 'background_color'      : '#000000',
                 'background_darkness'   : 0.5,
                 'background_type'       : 'solid',
-                'background_image'      : None,
                 'backspace_binding'     : 'ascii-del',
                 'delete_binding'        : 'escape-sequence',
                 'color_scheme'          : 'grey_on_black',
@@ -217,9 +216,8 @@ DEFAULTS = {
                 'cursor_shape'          : 'block',
                 'cursor_color'          : '',
                 'cursor_color_fg'       : True,
-                'emulation'             : 'xterm',
                 'term'                  : 'xterm-256color',
-                'colorterm'             : 'gnome-terminal',
+                'colorterm'             : 'truecolor',
                 'font'                  : 'Mono 10',
                 'foreground_color'      : '#aaaaaa',
                 'show_titlebar'         : True,
@@ -233,9 +231,8 @@ DEFAULTS = {
                 'palette'               : '#2e3436:#cc0000:#4e9a06:#c4a000:\
 #3465a4:#75507b:#06989a:#d3d7cf:#555753:#ef2929:#8ae234:#fce94f:\
 #729fcf:#ad7fa8:#34e2e2:#eeeeec',
-                'word_chars'            : '-A-Za-z0-9,./?%&#:_',
+                'word_chars'            : '-,./?%&#:_',
                 'mouse_autohide'        : True,
-                'update_records'        : True,
                 'login_shell'           : False,
                 'use_custom_command'    : False,
                 'custom_command'        : '',
@@ -247,7 +244,7 @@ DEFAULTS = {
                 'force_no_bell'         : False,
                 'cycle_term_tab'        : True,
                 'copy_on_selection'     : False,
-                'alternate_screen_scroll': True,
+                'rewrap_on_resize'      : True,
                 'split_to_group'        : False,
                 'autoclean_groups'      : True,
                 'http_proxy'            : '',
@@ -366,11 +363,11 @@ class Config(object):
         """Look up the system font"""
         if self.system_prop_font is not None:
             return(self.system_prop_font)
-        elif 'gconf' not in globals():
+        elif 'GConf' not in globals():
             return
         else:
             if self.gconf is None:
-                self.gconf = gconf.client_get_default()
+                self.gconf = GConf.Client.get_default()
 
             value = self.gconf.get(
                         '/desktop/gnome/interface/font_name')
@@ -387,11 +384,11 @@ class Config(object):
         """Look up the system font"""
         if self.system_mono_font is not None:
             return(self.system_mono_font)
-        elif 'gconf' not in globals():
+        elif 'GConf' not in globals():
             return
         else:
             if self.gconf is None:
-                self.gconf = gconf.client_get_default()
+                self.gconf = GConf.Client.get_default()
 
             value = self.gconf.get(
                         '/desktop/gnome/interface/monospace_font_name')
@@ -408,11 +405,11 @@ class Config(object):
         """Look up the system focus setting"""
         if self.system_focus is not None:
             return(self.system_focus)
-        elif 'gconf' not in globals():
+        elif 'GConf' not in globals():
             return
         else:
             if self.gconf is None:
-                self.gconf = gconf.client_get_default()
+                self.gconf = GConf.Client.get_default()
 
             value = self.gconf.get('/apps/metacity/general/focus_mode')
             if value:
@@ -569,8 +566,6 @@ class ConfigBase(Borg):
                 keytype = keymap[keytype]
             elif keytype == 'list':
                 value = 'list(%s)' % ','.join(value)
-            if key == 'background_image':
-                keytype = 'string'
             if keytype == 'string':
                 value = '"%s"' % value
 
