@@ -5,7 +5,7 @@
 
 import copy
 import os
-import gtk
+from gi.repository import Gtk, Gdk
 
 from borg import Borg
 from config import Config
@@ -15,6 +15,20 @@ from factory import Factory
 from cwd import get_pid_cwd
 from version import APP_NAME, APP_VERSION
 
+def eventkey2gdkevent(eventkey):  # FIXME FOR GTK3: is there a simpler way of casting from specific EventKey to generic (union) GdkEvent?
+    gdkevent = Gdk.Event.new(eventkey.type)
+    gdkevent.key.window = eventkey.window
+    gdkevent.key.send_event = eventkey.send_event
+    gdkevent.key.time = eventkey.time
+    gdkevent.key.state = eventkey.state
+    gdkevent.key.keyval = eventkey.keyval
+    gdkevent.key.length = eventkey.length
+    gdkevent.key.string = eventkey.string
+    gdkevent.key.hardware_keycode = eventkey.hardware_keycode
+    gdkevent.key.group = eventkey.group
+    gdkevent.key.is_modifier = eventkey.is_modifier
+    return gdkevent
+
 class Terminator(Borg):
     """master object for the application"""
 
@@ -25,6 +39,7 @@ class Terminator(Borg):
     groups = None
     config = None
     keybindings = None
+    style_provider = None
     last_focused_term = None
 
     origcwd = None
@@ -89,10 +104,9 @@ class Terminator(Borg):
     def attempt_gnome_client(self):
         """Attempt to find a GNOME Session to register with"""
         try:
-            import gnome
-            import gnome.ui
-            self.gnome_program = gnome.init(APP_NAME, APP_VERSION)
-            self.gnome_client = gnome.ui.master_client()
+            from gi.repository import Gnome
+            self.gnome_program = Gnome.init(APP_NAME, APP_VERSION)  # VERIFY FOR GTK3
+            self.gnome_client = Gnome.Ui.master_client()  # VERIFY FOR GTK3
             self.gnome_client.connect_to_session_manager()
             self.gnome_client.connect('save-yourself', self.save_yourself)
             self.gnome_client.connect('die', self.die)
@@ -134,7 +148,7 @@ class Terminator(Borg):
         if len(self.windows) == 0:
             # We have no windows left, we should exit
             dbg('no windows remain, quitting')
-            gtk.main_quit()
+            Gtk.main_quit()
 
     def register_launcher_window(self, window):
         """Register a new launcher window widget"""
@@ -155,7 +169,7 @@ class Terminator(Borg):
         if len(self.launcher_windows) == 0 and len(self.windows) == 0:
             # We have no windows left, we should exit
             dbg('no windows remain, quitting')
-            gtk.main_quit()
+            Gtk.main_quit()
 
     def register_terminal(self, terminal):
         """Register a new terminal widget"""
@@ -354,14 +368,23 @@ class Terminator(Borg):
     def reconfigure(self):
         """Update configuration for the whole application"""
 
+        if self.style_provider is not None:
+            Gtk.StyleContext.remove_provider_for_screen(
+                Gdk.Screen.get_default(),
+                self.style_provider)
+            self.style_provider = None
         if self.config['handle_size'] in xrange(0, 6):
-            gtk.rc_parse_string("""
-                style "terminator-paned-style" {
-                    GtkPaned::handle_size = %s 
+            css = """
+                GtkPaned {
+                    -GtkPaned-handle-size: %s
                 }
-                class "GtkPaned" style "terminator-paned-style" 
-                """ % self.config['handle_size'])
-            gtk.rc_reset_styles(gtk.settings_get_default())
+                """ % self.config['handle_size']
+            self.style_provider = Gtk.CssProvider()
+            self.style_provider.load_from_data(css)
+            Gtk.StyleContext.add_provider_for_screen(
+                Gdk.Screen.get_default(), 
+                self.style_provider,     
+                Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
 
         # Cause all the terminals to reconfigure
         for terminal in self.terminals:
@@ -416,13 +439,13 @@ class Terminator(Borg):
                 group)
         for term in self.terminals:
             if term != terminal and term.group == group:
-                term.vte.emit(type, event)
+                term.vte.emit(type, eventkey2gdkevent(event))
 
     def all_emit(self, terminal, type, event):
         """Emit to all terminals"""
         for term in self.terminals:
             if term != terminal:
-                term.vte.emit(type, event)
+                term.vte.emit(type, eventkey2gdkevent(event))
 
     def do_enumerate(self, widget, pad):
         """Insert the number of each terminal in a group, into that terminal"""
@@ -459,7 +482,7 @@ class Terminator(Borg):
     def get_focussed_terminal(self):
         """iterate over all the terminals to find which, if any, has focus"""
         for terminal in self.terminals:
-            if terminal.flags()&gtk.HAS_FOCUS:
+            if terminal.has_focus():
                 return(terminal)
         return(None)
 
